@@ -4,7 +4,7 @@ import re
 import copy
 
 elem_re = re.compile(r'(<\?[^>]+\?>|<![^>]+>|<\/|\/>|<|>|[^<>\s]+|\s+)', re.DOTALL | re.MULTILINE)
-attrib_re = re.compile(r'\s*([^=]+)="([^=]*)"')
+attrib_re = re.compile(r'\s*([^=]+)="([^"]*)"')
 SEQ_TYPES = (list, tuple)
 
 class Element(object):
@@ -40,6 +40,7 @@ class Element(object):
         try:
             while 1:
                 text = next(contentiter).group(1)
+                #print('>>> here %s' % text)
 
                 if text.startswith('<?'):
                     current_elem.children.append(TextElement(text))
@@ -51,6 +52,7 @@ class Element(object):
                     template.check_element(current_elem)
                     # dump tag
                     tag = next(contentiter).group(1)
+                    #print('>>> here %s' % tag)
 
                     current_elem = current_elem.parent
 
@@ -274,18 +276,21 @@ class Template(object):
             elems = self.__element_ids[eid]
             if index < len(elems):
                 elem = elems[index]
+                current_pos = elem.parent.children.index(elem)
                 elem.parent.children.remove(elem)
                 replacement_type = type(replacement)
                 if replacement_type in (Element, TextElement):
                     self.check_element(replacement, True)
-                    elem.parent.children.append(replacement)
+                    elem.parent.children.insert(current_pos, replacement)
                 elif replacement_type == Template:
-                    elem.parent.children += replacement.root.children
+                    for child in replacement.root.children:
+                        elem.parent.children.insert(current_pos, child)
+                        current_pos += 1
                     self.__merge_ids(self.__element_ids, replacement.__element_ids)
                     self.__merge_ids(self.__attrib_ids, replacement.__attrib_ids)
                     self.__merge_ids(self.__repeat_ids, replacement.__repeat_ids)
                 else:
-                    elem.parent.children.append(TextElement(replacement))
+                    elem.parent.children.insert(current_pos, TextElement(replacement))
 
     def __merge_ids(self, self_ids, ids):
         for key,val in ids.items():
